@@ -127,31 +127,11 @@ class GoodsCopyUtils:
                     result.append(value)
                 elif isinstance(value, dict):
                     queue.append(value)
+                elif isinstance(value, list):
+                    for dic in value:
+                        queue.append(dic)
         if result:
-            return result[0]
-
-
-class Headers:
-
-    def headers(self, referer=None, mobile_headers=None):
-        while True:
-            user_agent = fake.chrome(
-                version_from=63, version_to=80, build_from=999, build_to=3500
-            )
-            if "Android" in user_agent or "CriOS" in user_agent:
-                if mobile_headers:
-                    break
-                continue
-            else:
-                break
-        if referer:
-            return {
-                "user-agent": user_agent,
-                "referer": referer,
-            }
-        return {
-            "user-agent": user_agent,
-        }
+            return result[-1]
 
 
 class Cookies(object):
